Ocyan plugin wagtail_2fa
========================
Installation
-------------
Add `ocyan.plugin.wagtail_2fa` to your projects dependencies.

Add `WAGTAIL_2FA_REQUIRED = True` to your production settings (*settings/env/prd.py*) or wherever you want to turn it on.


About & Usage of wagtail_2fa
----------------------------
This plugin adds two factor authentication to Wagtail for superusers. This allows you to use various apps like Authy, Google Authenticator or 1Password.

This plugin makes sure that everytime the superuser closes the browser, should be asked for the 2FA code again.

Client documentation is available on:
[Highbiza Wiki](https://highbiza.nl/wiki/documentatie-2fa/).
